.. _doc-data_model:

########################
  Build in data models
########################

:Release: |version|
:Date: |today|

Camelot comes with a number of build in data models.  To avoid boiler plate
models needed in almost any application (like Persons, Addresses, etc.), the
developer is encouraged to use these data models as a start for developing
custom applications.

.. _model-persons:

Persons and Organizations
=========================

.. automodule:: camelot.model.authentication
   :members:
   
Batch Jobs
==========

.. automodule:: camelot.model.batch_job
   :members:


Auditing
========

.. automodule:: camelot.model.memento
   :members:
